OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Požiadavka zlyhala, sieťové pripojenie nie je dostupné!",
    "Request unauthorized. Are you logged in?" : "Neautorizovaná požiadavka. Ste prihlásený?",
    "Request forbidden. Are you an admin?" : "Požiadavka zakázaná. Ste admin?",
    "Token expired or app not enabled! Reload the page!" : "Tokenu vypršala platnosť alebo app nie je povolená! Obnovte prosím stránku!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Vnútorná chyba servera! Skontrolujte prosím súbor data/nextcloud.log pre podrobnejšie informácie!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Požiadavka zlyhala, Nextcloud je momentálne v režime údržby!",
    "Can not add feed: Exists already" : "Nemožno pridať kanál: Už existuje",
    "Articles without feed" : "Články bez zdroja",
    "Can not add folder: Exists already" : "Nemožno pridať priečinok: Už existuje",
    "News" : "Správy",
    "An RSS/Atom feed reader" : "RSS/Atom čítačka",
    "Use system cron for updates" : "Použiť systémový plánovač cron pre aktualizácie",
    "Disable this if you run a custom updater such as the Python updater included in the app" : "Vypnite, ak používate vlastnú aplikáciu pre aktulizácie, napr. Python aktualizácie zahrnuté v aplikácii",
    "Purge interval" : "Vynulovať interval",
    "Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored" : "Minimálny čas v sekundách, po ktorom sú z databázy vymazané odstránené kanály a priečinky; hodnoty menšie ako 60 sekúnd sú odignorované",
    "Maximum read count per feed" : "Maximálny počet noviniek pre kanál",
    "Defines the maximum amount of articles that can be read per feed which won't be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off" : "Určuje najvyšší počet článkov, ktoré sú dostupné na prečítanie z jednotlivých kanálov a nebudú zmazané pri čistení; ak sa staré články po prečítaní znovu objavia, navýšte túto hodnotu; záporné hodnoty ako napr. -1 túto funkciu vypnú",
    "Maximum redirects" : "Maximum presmerovaní",
    "How many redirects the feed fetcher should follow" : "Koľko presmerovaní sa má sledovať pri sťahovaní článkov",
    "Maximum feed page size" : "Maximálna veľkosť stránky kanálu",
    "Maximum feed size in bytes. If the RSS/Atom page is bigger than this value, the update will be aborted" : "Maximálna veľkosť zdroja v bajtoch. Aj je RSS/Atom stránka väčšia ako táto hodnota, potom bude tento update zastavený",
    "Feed fetcher timeout" : "Vypršal čas pre sťahovanie článkov",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted" : "Maximálna hodnota v sekundách pre aktualizáciu RSS alebo Atom zdroja; ak sa prekročí, aktualizácia sa ukončí",
    "Explore Service URL" : "Prehľadať URL služby",
    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty" : "Ak je zadané, bude táto URL služba dopytovať pre zobrazenie kanálov v sekcii prehľadávania kanálu. Pre návrat k prednastavenej službe prehľadávania ponechajte toto pole prázdne",
    "For more information check the wiki" : "Viac informácií nájdete v našej wiki",
    "Saved" : "Uložené",
    "Download" : "Sťahovanie",
    "Close" : "Zavrieť",
    "filter" : "filter",
    "Language" : "Jazyk",
    "Subscribe" : "Prihlásiť odber",
    "Got more awesome feeds? Share them with us!" : "Viete o ďalších úžasných kanáloch? Podeľte sa s nami o ne!",
    "No articles available" : "Žiadne články nie sú dostupné",
    "No unread articles available" : "Žiadne neprečítané články nie sú dostupné",
    "Open website" : "Otvoriť webstránku",
    "Star article" : "Prideliť hviezdičku",
    "Unstar article" : "Odobrať hviezdičku",
    "Keep article unread" : "Ponechať ako neprečítaný",
    "Remove keep article unread" : "Odstrániť označenie ako neprečítaný",
    "by" : "od",
    "from" : "z",
    "Play audio" : "Prehrávanie audia",
    "Download video" : "Stiahnuť video",
    "Download audio" : "Stiahnuť audio",
    "Keyboard shortcut" : "Klávesová skratka",
    "Description" : "Popis",
    "right" : "vpravo",
    "Jump to next article" : "Ísť na ďalší článok",
    "left" : "vľavo",
    "Jump to previous article" : "Ísť na predošlý článok",
    "Toggle star article" : "Prepnúť hviezdičku",
    "Star article and jump to next one" : "Označiť článok hviezdičkou a ísť na ďalší",
    "Toggle keep current article unread" : "Prepnúť ponechanie článku ako neprečítaný",
    "Open article in new tab" : "Otvoriť článok na novej karte",
    "Toggle expand article in compact view" : "Otvoriť článok v kompaktnom náhľade",
    "Refresh" : "Obnoviť",
    "Load next feed" : "Načítať ďalší kanál",
    "Load previous feed" : "Načítať predošlý kanál",
    "Load next folder" : "Načítať ďalší priečinok",
    "Load previous folder" : "Načítať predošlý priečinok",
    "Scroll to active navigation entry" : "Posunte na aktiváciu položky menu",
    "Focus search field" : "Zamerať na pole vyhľadávania",
    "Mark current article's feed/folder read" : "Označiť aktuálny kanál/priečinok článku ako prečítaný",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Bol zistený ajax alebo webcron mód. Vaše kanály sa nebudú aktualizovať!",
    "How to set up the operating system cron" : "Ako nastaviť cron v operačnom systéme",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Nainštalovať a nastaviť rýchlejší paralelný systém aktualizácie používajúci aktualizačné API modulu Noviniek",
    "Web address" : "Web adresa",
    "Feed exists already!" : "Kanál už existuje!",
    "Folder" : "Priečinok",
    "No folder" : "Žiaden priečinok",
    "New folder" : "Nový priečinok",
    "Folder name" : "Názov priečinka",
    "Go back" : "Ísť späť",
    "Folder exists already!" : "Priečinok už existuje!",
    "Credentials" : "Prihlasovanie údaje",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Prihlasovacie údaje pre HTTP Basic Auth musia byť uložené nezašifrované! Každý s prístupom k serveru alebo databáze si ich bude môcť prečítať!",
    "Username" : "Používateľské meno",
    "Password" : "Heslo",
    "New Folder" : "Nový priečinok",
    "Create" : "Vytvoriť",
    "Explore" : "Preskúmať",
    "Update failed more than 50 times" : "Aktualizácia zlyhala viac než 50 krát",
    "Deleted feed" : "Zmazaný kanál",
    "Undo delete feed" : "Obnoviť zmazaný kanál",
    "Rename" : "Premenovať",
    "Menu" : "Menu",
    "Mark read" : "Označ ako prečítané",
    "Unpin from top" : "Odobnuť zhora",
    "Pin to top" : "Pripnúť nahor",
    "Newest first" : "Od najnovších",
    "Oldest first" : "Od najstarších",
    "Default order" : "Predvolené poradie",
    "Enable full text" : "Povoliť plný text",
    "Disable full text" : "Zakázať plný text",
    "Unread updated" : "Aktualizovali sa neprečítané",
    "Ignore updated" : "Ignorovať aktualizáciu",
    "Open feed URL" : "Otvoriť adresu zdroja",
    "Delete" : "Zmazať",
    "Dismiss" : "Odmietnuť",
    "Collapse" : "Zvinúť",
    "Deleted folder" : "Zmazaný priečinok",
    "Undo delete folder" : "Obnoviť zmazaný priečinok",
    "Starred" : "S hviezdičkou",
    "Unread articles" : "Neprečítané články",
    "All articles" : "Všetky články",
    "Settings" : "Nastavenia",
    "Disable mark read through scrolling" : "Vypnúť označovanie ako prečítané pri posune",
    "Compact view" : "Kompaktný náhľad",
    "Expand articles on key navigation" : "Rozbaliť články po stlačení kláves navigácie",
    "Show all articles" : "Zobraziť všetky články",
    "Reverse ordering (oldest on top)" : "Opačné zoradenie (od najstarších)",
    "Subscriptions (OPML)" : "Odber (OPML)",
    "Import" : "Import",
    "Export" : "Export",
    "Error when importing: File does not contain valid OPML" : "Chyba počas importovania: súbor neobsahuje platné OPML údaje",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Chyba počas importovania: OPML neobsahuje kanály ani priečinky",
    "Unread/Starred Articles" : "Neprečítané články s hviezdičkou",
    "Error when importing: file does not contain valid JSON" : "Chyba pri importe: súbor neobsahuje platný JSON",
    "Help" : "Pomoc",
    "Keyboard shortcuts" : "Klávesové skratky",
    "Documentation" : "Dokumentácia",
    "Report a bug" : "Nahlásiť chybu"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
